package net.fckeditor.tool;

import java.util.LinkedHashMap;
import java.util.Map;

public class UploadResponse {

	private Map<String, Object> parameters;

	// TODO Rename 'En_'-constants to something more intuitive like 'CODE_'
	public static final int EN_OK = 0;
	public static final int EN_ERROR = 1;
	public static final int EN_WARNING = 101;
	public static final int EN_RENAMED = 201;
	public static final int EN_INVALID_EXTENSION = 202;
	public static final int EN_SECURITY_ERROR = 203;
	public static final int EN_GENERIC_NUMBER = -1;

	public static final String CM_HTTP_400 = "400 Bad request";
	private static final String[] paramNames = {"errorNumber","fileUrl","filename","customMessage"};

	public static final UploadResponse UR_INVALID_EXTENSION = new UploadResponse(
			EN_INVALID_EXTENSION);
	public static final UploadResponse UR_SECURITY_ERROR = new UploadResponse(
			EN_SECURITY_ERROR);
	public static final UploadResponse UR_GENERIC_NUMBER = new UploadResponse(
			EN_GENERIC_NUMBER);

	public UploadResponse(Object... arguments) throws IllegalArgumentException {
		if (arguments.length < 1 || arguments.length > 4)
			throw new IllegalArgumentException(
					"The amount of arguments has to be between 1 and 4");

		parameters = new LinkedHashMap<String, Object>(arguments.length);

		if (arguments[0] instanceof Integer)
			parameters.put(UploadResponse.paramNames[0], arguments[0]);
		else
			throw new IllegalArgumentException(
					"The first argument has to be an error number (int)");
		
		for (int i = 1; i < arguments.length; i++)
			parameters.put(UploadResponse.paramNames[i], arguments[i]);

	}

	public void setCustomMessage(final String customMassage) {
		if (Utils.isNotEmpty(customMassage)) {
			if (parameters.size() == 1) {
				parameters.put(UploadResponse.paramNames[1], null);
				parameters.put(UploadResponse.paramNames[2], null);
			}
			parameters.put(UploadResponse.paramNames[3], customMassage);
		}
	}

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder(75);
		sb.append("<script type=\"text/javascript\">\n");
		sb.append("window.parent.OnUploadCompleted(");

		for (Object parameter : parameters.values()) {
			if (parameter instanceof Integer) {
				sb.append(parameter);
			} else {
				sb.append("'");
				if (parameter != null)
					sb.append(parameter);
				sb.append("'");
			}
			sb.append(",");
		}
		
		sb.deleteCharAt(sb.length() - 1);
		sb.append(");\n");
		sb.append("</script>");

		return sb.toString();
	}
}
